@@ -240,11 +240,11 @@ def getFileMD5(file):
 
 
 def getFileCRC(file):
-    return getDataCRCHex(readBinFile(file))
+    return getDataCRC(readBinFile(file))
 
 
 def getContentCRC(content):
-    return getDataCRCHex(content.decode())
+    return getDataCRC(content.encode())
 
 
 def getDataCRC(data):
